Installation
============
The latest stable code can be installed from `PyPI <https://pypi.python.org/pypi/diffupath>`_ with:

.. code-block:: sh

   $ python3 -m pip install diffupath

The most recent code can be installed from the source on `GitHub <https://github.com/multipaths/diffupath>`_ with:

.. code-block:: sh

   $ python3 -m pip install git+https://github.com/multipaths/diffupath.git

For developers, the repository can be cloned from `GitHub <https://github.com/multipaths/diffupath>`_ and installed in
editable mode with:

.. code-block:: sh

   $ git clone https://github.com/multipaths/diffupath.git
   $ cd diffupath
   $ python3 -m pip install -e .

Requirements
------------
``diffupath`` requires the following libraries: ::

    networkx (>=2.1)
    pybel (0.13.2)
    biokeen (0.0.14)
    click (7.0)
    tqdm (4.31.1)
    numpy (1.16.3)
    scipy (1.2.1)
    scikit-learn (0.21.3)
    pandas (0.24.2)
    openpyxl (3.0.2)
    plotly (4.5.3)
    matplotlib (3.1.2)
    matplotlib_venn (0.11.5)
    bio2bel (0.2.1)
    pathme
    diffupy
